@@ -44,9 +44,29 @@ def read_excel(file_name: str) -> pd.DataFrame:
 
 
 def read_csv(file_name: str) -> pd.DataFrame:
-  # this is probably a text-based flat-file
-  # TODO: skip rows
-  first_lines = read_first_n_lines(file_name, 4)
+  # determine what the delimiter is
+  first_lines = read_first_n_lines(file_name, 5)
   delimiter = detect_delimiter(first_lines)
   print(f"delimiter used: {delimiter}")
-  return pd.read_csv(file_name, delimiter=delimiter, dtype=str, engine='python', encoding='cp437', index_col=False)
\ No newline at end of file
+  # determine if we need to skip some silly header rows (i.e., Excel converted to CSV)
+  skip_rows = csv_skip_rows(first_lines, delimiter)
+  return pd.read_csv(
+    file_name, 
+    delimiter=delimiter, 
+    skiprows=skip_rows, 
+    dtype=str, 
+    engine='python', 
+    encoding='cp437', 
+    index_col=False)
+
+
+def csv_skip_rows(first_lines: str, delimiter: str) -> int:
+  skip = 0
+  lines = first_lines.split('\n')
+  for line in lines:
+    cells = [x.strip() for x in line.split(delimiter)]
+    print(f"skip={skip}, cells={cells}")
+    if len(cells) > 1 and (cells[0] != ''):
+      return skip
+    skip += 1
+  return skip
